import * as i0 from '@angular/core';
import { inject, ChangeDetectorRef, EventEmitter, ElementRef, HostAttributeToken, HostListener, HostBinding, Input, Output, Component } from '@angular/core';
import { NgControl, NgForm, FormGroupDirective, Validators } from '@angular/forms';
import { FocusMonitor } from '@angular/cdk/a11y';
import { coerceBooleanProperty, coerceArray } from '@angular/cdk/coercion';
import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i2 from '@angular/material/chips';
import { MatChipsModule } from '@angular/material/chips';
import * as i3 from '@angular/material/datepicker';
import { MatDatepicker, MatCalendar, MatDatepickerModule } from '@angular/material/datepicker';
import { MatFormFieldModule, MatFormFieldControl } from '@angular/material/form-field';
import * as i4 from '@angular/material/icon';
import { MatIconModule } from '@angular/material/icon';
import * as i5 from '@angular/material/input';
import { MatInputModule } from '@angular/material/input';
import { DateAdapter, ErrorStateMatcher } from '@angular/material/core';
import { Subject } from 'rxjs';
import { takeUntil } from 'rxjs/operators';

class MultipleDatesBaseMixinBase {
    $elementRef;
    _defaultErrorStateMatcher;
    _parentForm;
    _parentFormGroup;
    ngControl;
    /**
     * Stream that emits whenever the state of the control changes such that the parent
     * `MatFormField` needs to run change detection.
     */
    stateChanges = new Subject();
    constructor($elementRef, _defaultErrorStateMatcher, _parentForm, _parentFormGroup, ngControl) {
        this.$elementRef = $elementRef;
        this._defaultErrorStateMatcher = _defaultErrorStateMatcher;
        this._parentForm = _parentForm;
        this._parentFormGroup = _parentFormGroup;
        this.ngControl = ngControl;
    }
}
// Temporarily disable mixins until we find the correct API
const _MultipleDatesBaseMixinBase = MultipleDatesBaseMixinBase;
/**
 * Multiple dates component.
 * @template D Date type.
 */
class MultipleDatesComponent extends _MultipleDatesBaseMixinBase {
    ngControl;
    $elementRef;
    _changeDetectorRef = inject(ChangeDetectorRef);
    _focusMonitor = inject(FocusMonitor);
    _dateAdapter = inject(DateAdapter);
    static nextId = 0;
    /** Unique id of the element. */
    id = `ngx-multiple-dates-${MultipleDatesComponent.nextId++}`;
    describedBy = '';
    /** Whether the control is in an error state. */
    errorState = false;
    /** An object used to control when error messages are shown. */
    errorStateMatcher;
    tabIndex;
    /**
     * The date/time components to include, using predefined options or a custom format string.
     * @see {@link https://angular.io/api/common/DatePipe#usage-notes DatePipe Usage notes} for more
     * information.
     */
    format;
    /** Emits when a change event is fired on this `ngx-multiple-dates` element. */
    dateChange = new EventEmitter();
    /** Emits on a date removal. */
    remove = new EventEmitter();
    /** Whether `ngx-multiple-dates` element has focus. */
    focused = false;
    /** A name for this control that can be used by mat-form-field. */
    controlType = 'ngx-multiple-dates';
    /**
     * Model used to reset datepicker selected value, so unselect just selected date will be
     * possible.
     */
    resetModel;
    _destroy = new Subject();
    /**
     * The datepicker (or calendar - for inline view) that this `ngx-multiple-dates` element is
     * associated with.
     */
    _matDatepicker;
    /** Whether datepicker should be closed on date selected, or opened to select more dates. */
    _closeOnSelected = false;
    /** Placeholder to be shown if no value has been selected. */
    _placeholder;
    /** Whether the component is required. */
    _required = false;
    /** Whether the component is disabled. */
    _disabled = false;
    /** The value of the `ngx-multiple-dates` control. */
    _value = [];
    /**
     * Theme color palette for the component. This API is supported in M2 themes only, it has no
     * effect in M3 themes.
     * For information on applying color variants in M3, see
     * https://material.angular.io/guide/theming#using-component-color-variants.
     */
    _color = null;
    /** Function that can be used to filter out dates within the datepicker. */
    _dateFilter;
    /** The minimum valid date. */
    _min;
    /** The maximum valid date. */
    _max;
    /** Custom date classes. */
    // eslint-disable-next-line @typescript-eslint/array-type
    _classes = [];
    _validator;
    // eslint-disable-next-line @typescript-eslint/no-explicit-any, @typescript-eslint/no-empty-function
    _onChange = () => { };
    // eslint-disable-next-line @typescript-eslint/no-empty-function
    _onTouched = () => { };
    // eslint-disable-next-line @typescript-eslint/no-empty-function
    _onValidatorChange = () => { };
    _filterValidator = (control) => {
        const value = this._getValidDateOrNull(this._dateAdapter.deserialize(control.value));
        return !this._dateFilter || !value || this._dateFilter(value)
            ? null
            : { matDatepickerFilter: true };
    };
    _minValidator = (control) => {
        const value = this._getValidDateOrNull(this._dateAdapter.deserialize(control.value));
        return (!this.min || !value || this._dateAdapter.compareDate(this.min, value) <= 0)
            ? null
            : { matDatepickerMin: { min: this.min, actual: value } };
    };
    _maxValidator = (control) => {
        const value = this._getValidDateOrNull(this._dateAdapter.deserialize(control.value));
        return (!this.max || !value || this._dateAdapter.compareDate(this.max, value) >= 0)
            ? null
            : { matDatepickerMax: { max: this.max, actual: value } };
    };
    /**
     * The datepicker (or calendar - for inline view) that this `ngx-multiple-dates` element is
     * associated with.
     */
    get matDatepicker() {
        return this._matDatepicker;
    }
    set matDatepicker(value) {
        if (!value || (!(value instanceof MatDatepicker) && !(value instanceof MatCalendar))) {
            throw new TypeError(`Either "matDatepicker" or "matCalendar" attribute of "ngx-multiple-dates" is required and
        should be an instance of Angular Material Datepicker component.`);
        }
        this._matDatepicker = value;
        if (this.matDatepicker instanceof MatDatepicker) {
            this.matDatepicker.closedStream
                .pipe(takeUntil(this._destroy))
                .subscribe(() => this.blur());
        }
        else {
            this.matDatepicker.selectedChange
                .pipe(takeUntil(this._destroy))
                .subscribe((event) => this.dateChanged({ value: event }));
        }
        if (!this.matDatepicker.startAt) {
            this._setStartAt();
        }
        this._setDisabled();
        this._setDateClass();
    }
    /** Whether datepicker should be closed on date selected, or opened to select more dates. */
    get closeOnSelected() {
        return this._closeOnSelected;
    }
    set closeOnSelected(value) {
        this._closeOnSelected = coerceBooleanProperty(value);
    }
    /** Placeholder to be shown if no value has been selected. */
    get placeholder() {
        return this._placeholder;
    }
    set placeholder(value) {
        this._placeholder = value;
        this.stateChanges.next();
    }
    /** Whether the component is required. */
    get required() {
        return this._required;
    }
    set required(value) {
        this._required = coerceBooleanProperty(value);
        this.stateChanges.next();
    }
    /** Whether the component is disabled. */
    get disabled() {
        return this._disabled;
    }
    set disabled(value) {
        this._disabled = coerceBooleanProperty(value);
        this._setDisabled();
        if (this.focused) {
            this.focused = false;
            this.stateChanges.next();
        }
    }
    /** The value of the `ngx-multiple-dates` control. */
    get value() {
        if (!this._value) {
            this._value = [];
        }
        return this._value;
    }
    set value(value) {
        if (value !== this._value) {
            this.writeValue(value);
        }
    }
    /**
     * Theme color palette for the component. This API is supported in M2 themes only, it has no
     * effect in M3 themes.
     * For information on applying color variants in M3, see
     * https://material.angular.io/guide/theming#using-component-color-variants.
     */
    get color() {
        return this._color;
    }
    set color(value) {
        this._color = value;
    }
    /** Function that can be used to filter out dates within the datepicker. */
    get matDatepickerFilter() {
        return this._dateFilter;
    }
    set matDatepickerFilter(value) {
        this._dateFilter = value;
        this._onValidatorChange();
    }
    /** The minimum valid date. */
    get min() {
        return this._min;
    }
    set min(value) {
        this._min = this._getValidDateOrNull(this._dateAdapter.deserialize(value));
        this._onValidatorChange();
    }
    /** The maximum valid date. */
    get max() {
        return this._max;
    }
    set max(value) {
        this._max = this._getValidDateOrNull(this._dateAdapter.deserialize(value));
        this._onValidatorChange();
    }
    /** Custom date classes. */
    get classes() {
        return this._classes;
    }
    // eslint-disable-next-line @typescript-eslint/array-type
    set classes(value) {
        this._classes = coerceArray(value);
    }
    /** Whether the `MatFormField` label should try to float. */
    get shouldLabelFloat() {
        return !this.empty || (this.focused && !this.disabled);
    }
    /** Whether the select has a value. */
    get empty() {
        return !this.value || !this.value.length;
    }
    /** Whether the settled picker is a datepicker. */
    get isDatepicker() {
        return this.matDatepicker instanceof MatDatepicker;
    }
    /**
     * Creates an instance of MultipleDatesComponent.
     * @param ngControl Form control to manage component.
     * @param $elementRef A wrapper around a native element inside of a View.
     * @param _changeDetectorRef Base class that provides change detection functionality.
     * @param _focusMonitor Monitors mouse and keyboard events to determine the cause of focus events.
     * @param _dateAdapter Adapts type `D` to be usable as a date by cdk-based components that work
     * with dates.
     * @param parentForm Parent form.
     * @param parentFormGroup Parent form group.
     * @param defaultErrorStateMatcher Provider that defines how form controls behave with regards to
     * displaying error messages.
     * @param tabIndex Tab index.
     */
    constructor() {
        const ngControl = inject(NgControl, { optional: true, self: true });
        const $elementRef = inject(ElementRef);
        const parentForm = inject(NgForm, { optional: true });
        const parentFormGroup = inject(FormGroupDirective, { optional: true });
        const defaultErrorStateMatcher = inject(ErrorStateMatcher);
        const tabIndex = inject(new HostAttributeToken('tabindex'), { optional: true });
        super($elementRef, defaultErrorStateMatcher, parentForm, parentFormGroup, ngControl);
        this.ngControl = ngControl;
        this.$elementRef = $elementRef;
        const _focusMonitor = this._focusMonitor;
        const _dateAdapter = this._dateAdapter;
        this.resetModel = _dateAdapter.createDate(0, 0, 1);
        const validators = [
            this._filterValidator,
            this._minValidator,
            this._maxValidator
        ];
        if (this.ngControl != null) {
            this.ngControl.valueAccessor = this;
            if (this.ngControl.validator) {
                validators.push(this.ngControl.validator);
            }
        }
        this._validator = Validators.compose(validators);
        _focusMonitor.monitor($elementRef.nativeElement, true)
            // eslint-disable-next-line @typescript-eslint/no-explicit-any
            .subscribe((origin) => {
            this.focused = !!origin;
            this.stateChanges.next();
        });
        this.tabIndex = Number(tabIndex) || 0;
    }
    ngAfterViewInit() {
        if (this.ngControl && this.ngControl.control) {
            this.ngControl.control.addValidators(this.validate.bind(this));
        }
        this._setStartAt();
        this._setDateClass();
    }
    ngOnDestroy() {
        this._destroy.next();
        this._destroy.complete();
        this.stateChanges.complete();
        this._focusMonitor.stopMonitoring(this.$elementRef.nativeElement);
    }
    ngDoCheck() {
        if (this.ngControl) {
            this._updateErrorState();
        }
    }
    _updateErrorState() {
        const oldState = this.errorState;
        const parent = this._parentFormGroup || this._parentForm;
        const matcher = this.errorStateMatcher || this._defaultErrorStateMatcher;
        const control = this.ngControl ? this.ngControl.control : null;
        const newState = matcher.isErrorState(control, parent);
        if (newState !== oldState) {
            this.errorState = newState;
            this.stateChanges.next();
        }
    }
    /** Focuses the `ngx-multiple-dates` element. */
    focus() {
        if (!this.disabled) {
            this.focused = true;
            if (this.matDatepicker && this.matDatepicker instanceof MatDatepicker) {
                this.matDatepicker.open();
            }
            this.stateChanges.next();
        }
    }
    /** Used to leave focus from the `ngx-multiple-dates` element. */
    blur() {
        this.focused = false;
        if (!this.disabled) {
            this._onTouched();
            this._changeDetectorRef.markForCheck();
            this.stateChanges.next();
        }
    }
    writeValue(value) {
        if (Array.isArray(value)) {
            this._value = [...value];
            this._sort();
        }
        else {
            this._value = value;
        }
        this._onChange(value);
        this.stateChanges.next();
    }
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    registerOnChange(fn) {
        this._onChange = fn;
    }
    registerOnTouched(fn) {
        this._onTouched = fn;
    }
    registerOnValidatorChange(fn) {
        this._onValidatorChange = fn;
    }
    /**
     * Sets the list of element IDs that currently describe this control.
     * @param ids Ids to set.
     */
    setDescribedByIds(ids) {
        this.describedBy = ids.join(' ');
    }
    /** Handles a click on the control's container. */
    onContainerClick() {
        if (!this.focused) {
            this.focus();
        }
    }
    /**
     * Performs synchronous validation for the control.
     * @param control The control to validate against.
     * @returns A map of validation errors if validation fails, otherwise null.
     */
    validate(control) {
        return this._validator ? this._validator(control) : null;
    }
    /**
     * Function used to add CSS classes to selected dates.
     * @param date Date to check if classes should be applied.
     * @returns CSS classes to apply.
     */
    dateClass = (date) => {
        let className;
        if (this.classes.length) {
            className = this.getClassName(date);
        }
        if (this._find(date) !== -1) {
            return ['selected', ...(className ? [className] : [])];
        }
        if (className) {
            return [className];
        }
        return [];
    };
    /**
     * Fires when a change event is fired on the datepicker `<input />`.
     * @param event Change event.
     */
    dateChanged(event) {
        if (event.value) {
            const date = event.value;
            if (this.value) {
                const index = this._find(date);
                if (index === -1) {
                    this.value.push(date);
                    this._sort();
                }
                else {
                    this.value.splice(index, 1);
                    this.remove.emit({ type: 'datepicker', date });
                }
            }
            this.resetModel = this._dateAdapter.createDate(0, 0, 1);
            this._setStartAt();
            if (this.matDatepicker && this.matDatepicker instanceof MatDatepicker
                && !this.closeOnSelected) {
                const closeFn = this.matDatepicker.close;
                // eslint-disable-next-line @typescript-eslint/no-empty-function
                this.matDatepicker.close = () => { };
                this.matDatepicker['_componentRef'].instance._calendar.monthView._createWeekCells();
                setTimeout(() => this.matDatepicker.close = closeFn);
                this._changeDetectorRef.detectChanges();
            }
            else if (this.matDatepicker instanceof MatCalendar) {
                // eslint-disable-next-line @typescript-eslint/no-explicit-any
                this.matDatepicker.monthView._createWeekCells();
            }
            this.writeValue(this.value);
        }
        this.dateChange.emit(event);
    }
    /**
     * Removes selected chip from the list.
     * @param date Value to remove.
     */
    removeChip(date) {
        if (this.value && this.value.length) {
            this._onTouched();
            const index = this._find(date);
            this.value.splice(index, 1);
            this.writeValue(this.value);
            if (this.matDatepicker instanceof MatCalendar) {
                // eslint-disable-next-line @typescript-eslint/no-explicit-any
                this.matDatepicker.monthView._createWeekCells();
                // eslint-disable-next-line @typescript-eslint/no-explicit-any
                this.matDatepicker.monthView._changeDetectorRef.detectChanges();
            }
            this.remove.emit({ type: 'chip', date });
            this._changeDetectorRef.detectChanges();
        }
    }
    trackByValue(_index, item) {
        return item;
    }
    getClassName(value) {
        for (const classValue of this.classes) {
            if (this._dateAdapter.compareDate(classValue.value, value) === 0) {
                return classValue.className;
            }
        }
        return undefined;
    }
    _setStartAt() {
        if (this.matDatepicker) {
            if (this.value && this.value.length) {
                this.matDatepicker.startAt = this.value[this.value.length - 1];
            }
            else {
                this.matDatepicker.startAt = this._dateAdapter.today();
            }
        }
    }
    _setDisabled() {
        if (this.matDatepicker && this.matDatepicker instanceof MatDatepicker) {
            this.matDatepicker.disabled = this.disabled;
        }
    }
    _setDateClass() {
        if (this.matDatepicker) {
            const dateClassFn = this.matDatepicker.dateClass;
            this.matDatepicker.dateClass = (date) => {
                const classList = this.dateClass(date);
                if (dateClassFn) {
                    const oldClasses = dateClassFn(date, 'month');
                    if (classList.length) {
                        if (oldClasses instanceof Set) {
                            for (const className of classList) {
                                oldClasses.add(className);
                            }
                        }
                        else if (oldClasses instanceof Array) {
                            for (const className of classList) {
                                oldClasses.push(className);
                            }
                        }
                        else if (typeof oldClasses === 'string') {
                            return [oldClasses, ...classList].join(' ');
                        }
                        else {
                            for (const className of classList) {
                                oldClasses[className] = className;
                            }
                        }
                        return oldClasses;
                    }
                    return oldClasses;
                }
                return classList;
            };
        }
    }
    _find(date) {
        if (!this.value) {
            return -1;
        }
        return this.value.map((value) => this._dateAdapter.compareDate(value, date)).indexOf(0);
    }
    _sort() {
        if (this.value) {
            this.value.sort((lhs, rhs) => this._dateAdapter.compareDate(lhs, rhs));
        }
    }
    _getValidDateOrNull(obj) {
        return (this._dateAdapter.isDateInstance(obj) && this._dateAdapter.isValid(obj)) ? obj : null;
    }
    getDateFormat(date) {
        return this._dateAdapter.format(date, this.format || undefined);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "20.1.0", ngImport: i0, type: MultipleDatesComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "20.1.0", type: MultipleDatesComponent, isStandalone: true, selector: "ngx-multiple-dates", inputs: { id: "id", errorStateMatcher: "errorStateMatcher", tabIndex: "tabIndex", format: "format", matDatepicker: "matDatepicker", closeOnSelected: "closeOnSelected", placeholder: "placeholder", required: "required", disabled: "disabled", value: "value", color: "color", matDatepickerFilter: "matDatepickerFilter", min: "min", max: "max", classes: "classes" }, outputs: { dateChange: "dateChange", remove: "remove" }, host: { listeners: { "focus": "focus()", "blur": "blur()" }, properties: { "id": "this.id", "attr.aria-describedby": "this.describedBy", "attr.aria-invalid": "this.errorState", "class.mat-form-field-invalid": "this.errorState", "attr.tabindex": "this.tabIndex", "attr.aria-label": "this.placeholder", "attr.aria-required": "this.required", "attr.disabled": "this.disabled", "class.floating": "this.shouldLabelFloat" } }, providers: [
            { provide: MatFormFieldControl, useExisting: MultipleDatesComponent }
        ], exportAs: ["ngxMultipleDates"], usesInheritance: true, ngImport: i0, template: "<mat-chip-grid #chipList [attr.aria-label]=\"placeholder\" (click)=\"focus()\">\n  @for (item of value; track trackByValue($index, item)) {\n    <mat-chip\n      removable (removed)=\"removeChip(item)\" [highlighted]=\"!!color\"\n      [color]=\"color\" [ngClass]='getClassName(item)'>\n      {{ getDateFormat(item) }}\n      <mat-icon matChipRemove [attr.aria-label]=\"'remove ' + getDateFormat(item)\">cancel</mat-icon>\n    </mat-chip>\n  }\n  @if (isDatepicker) {\n    <input matInput hidden [value]=\"resetModel\"\n      [matDatepicker]=\"matDatepicker\" [matDatepickerFilter]=\"matDatepickerFilter\"\n      [min]=\"min\" [max]=\"max\" [matChipInputFor]=\"chipList\" (dateChange)=\"dateChanged($event)\"\n      [placeholder]=\"placeholder\" />\n  } @else {\n    <input matInput hidden [value]=\"resetModel\" [min]=\"min\" [max]=\"max\"\n      [matChipInputFor]=\"chipList\" [placeholder]=\"placeholder\" />\n    }\n    @if (!value?.length) {\n      <input [matChipInputFor]=\"chipList\" [placeholder]=\"placeholder\" />\n    }\n  </mat-chip-grid>\n", styles: [":host{display:block;outline:none!important}:host span{opacity:0;transition:opacity .2s}:host.floating span{opacity:1}:host ::ng-deep mat-chip-list{outline:none!important}:host ::ng-deep mat-chip-list .mat-chip-list-wrapper{min-height:18px}:host ::ng-deep mat-chip-list .mat-chip-remove{outline:none!important}\n"], dependencies: [{ kind: "ngmodule", type: CommonModule }, { kind: "directive", type: i1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "ngmodule", type: MatChipsModule }, { kind: "component", type: i2.MatChip, selector: "mat-basic-chip, [mat-basic-chip], mat-chip, [mat-chip]", inputs: ["role", "id", "aria-label", "aria-description", "value", "color", "removable", "highlighted", "disableRipple", "disabled"], outputs: ["removed", "destroyed"], exportAs: ["matChip"] }, { kind: "component", type: i2.MatChipGrid, selector: "mat-chip-grid", inputs: ["disabled", "placeholder", "required", "value", "errorStateMatcher"], outputs: ["change", "valueChange"] }, { kind: "directive", type: i2.MatChipInput, selector: "input[matChipInputFor]", inputs: ["matChipInputFor", "matChipInputAddOnBlur", "matChipInputSeparatorKeyCodes", "placeholder", "id", "disabled", "readonly", "matChipInputDisabledInteractive"], outputs: ["matChipInputTokenEnd"], exportAs: ["matChipInput", "matChipInputFor"] }, { kind: "directive", type: i2.MatChipRemove, selector: "[matChipRemove]" }, { kind: "ngmodule", type: MatDatepickerModule }, { kind: "directive", type: i3.MatDatepickerInput, selector: "input[matDatepicker]", inputs: ["matDatepicker", "min", "max", "matDatepickerFilter"], exportAs: ["matDatepickerInput"] }, { kind: "ngmodule", type: MatFormFieldModule }, { kind: "ngmodule", type: MatIconModule }, { kind: "component", type: i4.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }, { kind: "ngmodule", type: MatInputModule }, { kind: "directive", type: i5.MatInput, selector: "input[matInput], textarea[matInput], select[matNativeControl],      input[matNativeControl], textarea[matNativeControl]", inputs: ["disabled", "id", "placeholder", "name", "required", "type", "errorStateMatcher", "aria-describedby", "value", "readonly", "disabledInteractive"], exportAs: ["matInput"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "20.1.0", ngImport: i0, type: MultipleDatesComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-multiple-dates', providers: [
                        { provide: MatFormFieldControl, useExisting: MultipleDatesComponent }
                    ], exportAs: 'ngxMultipleDates', standalone: true, imports: [
                        CommonModule,
                        MatChipsModule,
                        MatDatepickerModule,
                        MatFormFieldModule,
                        MatIconModule,
                        MatInputModule
                    ], template: "<mat-chip-grid #chipList [attr.aria-label]=\"placeholder\" (click)=\"focus()\">\n  @for (item of value; track trackByValue($index, item)) {\n    <mat-chip\n      removable (removed)=\"removeChip(item)\" [highlighted]=\"!!color\"\n      [color]=\"color\" [ngClass]='getClassName(item)'>\n      {{ getDateFormat(item) }}\n      <mat-icon matChipRemove [attr.aria-label]=\"'remove ' + getDateFormat(item)\">cancel</mat-icon>\n    </mat-chip>\n  }\n  @if (isDatepicker) {\n    <input matInput hidden [value]=\"resetModel\"\n      [matDatepicker]=\"matDatepicker\" [matDatepickerFilter]=\"matDatepickerFilter\"\n      [min]=\"min\" [max]=\"max\" [matChipInputFor]=\"chipList\" (dateChange)=\"dateChanged($event)\"\n      [placeholder]=\"placeholder\" />\n  } @else {\n    <input matInput hidden [value]=\"resetModel\" [min]=\"min\" [max]=\"max\"\n      [matChipInputFor]=\"chipList\" [placeholder]=\"placeholder\" />\n    }\n    @if (!value?.length) {\n      <input [matChipInputFor]=\"chipList\" [placeholder]=\"placeholder\" />\n    }\n  </mat-chip-grid>\n", styles: [":host{display:block;outline:none!important}:host span{opacity:0;transition:opacity .2s}:host.floating span{opacity:1}:host ::ng-deep mat-chip-list{outline:none!important}:host ::ng-deep mat-chip-list .mat-chip-list-wrapper{min-height:18px}:host ::ng-deep mat-chip-list .mat-chip-remove{outline:none!important}\n"] }]
        }], ctorParameters: () => [], propDecorators: { id: [{
                type: Input
            }, {
                type: HostBinding
            }], describedBy: [{
                type: HostBinding,
                args: ['attr.aria-describedby']
            }], errorState: [{
                type: HostBinding,
                args: ['attr.aria-invalid']
            }, {
                type: HostBinding,
                args: ['class.mat-form-field-invalid']
            }], errorStateMatcher: [{
                type: Input
            }], tabIndex: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['attr.tabindex']
            }], format: [{
                type: Input
            }], dateChange: [{
                type: Output
            }], remove: [{
                type: Output
            }], matDatepicker: [{
                type: Input
            }], closeOnSelected: [{
                type: Input
            }], placeholder: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['attr.aria-label']
            }], required: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['attr.aria-required']
            }], disabled: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['attr.disabled']
            }], value: [{
                type: Input
            }], color: [{
                type: Input
            }], matDatepickerFilter: [{
                type: Input
            }], min: [{
                type: Input
            }], max: [{
                type: Input
            }], classes: [{
                type: Input
            }], shouldLabelFloat: [{
                type: HostBinding,
                args: ['class.floating']
            }], focus: [{
                type: HostListener,
                args: ['focus']
            }], blur: [{
                type: HostListener,
                args: ['blur']
            }] } });

/**
 * Date class item.
 * @template D Date type.
 */
class DateClass {
    /** Date value. */
    value;
    /** CSS class name(s). */
    className;
}

/**
 * An event used for `ngx-multiple-dates` date removal.
 * @template D Date type.
 */
class DateRemoveEvent {
    /** Event type Specifies where the date was removed from (chip, datepicker). */
    type;
    /** Date removed. */
    date;
}

/*
 * Public API Surface of ngx-multiple-dates
 */

/**
 * Generated bundle index. Do not edit.
 */

export { DateClass, DateRemoveEvent, MultipleDatesComponent };
//# sourceMappingURL=ngx-multiple-dates.mjs.map
